# -*- coding: utf-8 -*-
# Moovida - Home multimedia server
# Copyright (C) 2009 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Moovida with Fluendo's plugins.
#
# The GPL part of Moovida is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Moovida" in the root directory of this distribution package
# for details on that license.
#
# Author: Jesús Corrius i Llavina <jcorrius@fluendo.com>

from elisa.core import common
from elisa.core.media_uri import MediaUri
from elisa.core.utils import defer
from elisa.core.components.model import Model

from elisa.plugins.base.models.media import PlayableModel
from elisa.plugins.base.models.audio import AlbumModel as DatabaseAlbumModel, \
                                            TrackModel as DatabaseTrackModel

class AlbumModel(DatabaseAlbumModel):
    """    
    """
    def __init__(self):
        super(AlbumModel, self).__init__()
        self.jamendo_id = None
        self.uri = None
        self.thumbnail = None
        self.name = None

    def get_tracks(self):
        if self.tracks:
            return defer.succeed(self.tracks)

        def resource_loaded(result, items):
            self.tracks.extend(items.list)
            return self.tracks

        uri = MediaUri("http://api.jamendo.com/get2/id+name+url+artist_name/track/json/album_track+album_artist/?n=all&album_id=%s&order=numalbum_asc" % self.jamendo_id)
        items, deferred = common.application.resource_manager.get(uri)
        deferred.addCallback(resource_loaded, items)
        return deferred


class AlbumModelList(Model):
    """
    """
    def __init__(self):
        super(AlbumModelList, self).__init__()
        self.list = []

class TrackModel(DatabaseTrackModel):
    """    
    """
    def __init__(self):
        super(TrackModel, self).__init__()
        self.jamendo_id = None
        self.uri = None

    def get_playable_model(self):
        playable_model = PlayableModel()
        playable_model.title = self.title
        if self.playable_uri is not None: 
            playable_model.uri = MediaUri(self.playable_uri)
        else:
            uri_split = self.uri.split('/')
            track_id = uri_split[len(uri_split)-1]
            playable_model.uri = MediaUri("http://api.jamendo.com/get2/stream/track/redirect/?id=%s&streamencoding=ogg2" % track_id)
        return defer.succeed(playable_model)

    def get_album(self):
        if self.album is not None:
            return defer.succeed(self.album)

        def resource_loaded(result, items):
            if len(items.list) > 0:
                self.album = items.list[0]
            return self.album

        uri = MediaUri("http://api.jamendo.com/get2/id+name+url+image+artist_name/album/json/album_track/?track_id=%s&imagesize=600" % self.jamendo_id)
        items, deferred = common.application.resource_manager.get(uri)
        deferred.addCallback(resource_loaded, items)
        return deferred

class TrackModelList(Model):
    """
    """
    def __init__(self):
        super(TrackModelList, self).__init__()
        self.list = []

class TagModel(Model):
    """
    """
    def __init__(self):
        super(TagModel, self).__init__()
        self.jamendo_id = None
        self.uri = None
        self.title = None

class TagModelList(Model):
    """
    """
    def __init__(self):
        super(TagModelList, self).__init__()
        self.list = []

class ArtistModel(Model):
    """
    """
    def __init__(self):
        super(ArtistModel, self).__init__()
        self.jamendo_id = None
        self.name = None
        self.image_uri = None
        self.tracks = []

    def get_tracks(self):
        if self.tracks:
            return defer.succeed(self.tracks)

        def resource_loaded(result, items):
            if len(items.list) > 0:
                self.tracks.extend(items.list)
            return self.tracks

        uri = MediaUri("http://api.jamendo.com/get2/id+name+url+artist_name/track/jsonpretty/track_album+album_artist/?artist_id=%s&n=all" % self.jamendo_id)
        items, deferred = common.application.resource_manager.get(uri)
        deferred.addCallback(resource_loaded, items)
        return deferred

class ArtistModelList(Model):
    """
    """
    def __init__(self):
        super(ArtistModelList, self).__init__()
        self.list = []

class RadioModel(Model):
    """
    """
    def __init__(self):
        super(RadioModel, self).__init__()
        self.jamendo_id = None
        self.title = None
        self.uri = None

class RadioModelList(Model):
    """
    """
    def __init__(self):
        super(RadioModelList, self).__init__()
        self.list = []

