# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2009 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.
#
# Author: Jesús Corrius i Llavina <jcorrius@fluendo.com>

import os
from setuptools import setup
from elisa.core.utils.dist import find_packages, TrialTest, Clean, build_po


packages, package_dir = find_packages(os.path.dirname(__file__))
cmdclass = dict(test=TrialTest, clean=Clean, build_po=build_po)


setup(name='elisa-plugin-jamendo',
    version='0.1.1',
    description='Jamendo, open your ears',
    long_description='On Jamendo artists allow anyone to download and share their music.',
    license='GPLv3',
    author='Moovida Developers',
    author_email='elisa@lists.fluendo.com',
    namespace_packages=['elisa', 'elisa.plugins'],
    packages=packages,
    package_dir=package_dir,
    package_data={'': ['*.conf', '*.png', 'icons/*'],
                  'elisa.plugins.jamendo.i18n': ['*/LC_MESSAGES/*.po', '*.pot'],
                  },
    cmdclass=cmdclass,
    entry_points="""
    [elisa.core.components.resource_provider]
    JamendoResourceProvider = elisa.plugins.jamendo.resource_provider:JamendoResourceProvider

    [elisa.core.plugin_registry]
    use = elisa.plugins.jamendo.controller:use_me_hook
    """,
    controller_mappings=[('/poblesec/jamendo',
                          'elisa.plugins.jamendo.controller:JamendoPreviewListController'),
                         ('/poblesec/jamendo/albums',
                          'elisa.plugins.jamendo.controller:JamendoAlbumsPreviewListController'),
                         ('/poblesec/jamendo/album/list',
                          'elisa.plugins.jamendo.controller:JamendoAlbumTracksListController'),
                         ('/poblesec/jamendo/album/more',
                          'elisa.plugins.jamendo.controller:JamendoAlbumMoreOptionsController'),
                         ('/poblesec/jamendo/artists',
                          'elisa.plugins.jamendo.controller:JamendoArtistsPreviewListController'),
                          ('/poblesec/jamendo/artist/more',
                          'elisa.plugins.jamendo.controller:JamendoArtistMoreOptionsController'),
                         ('/poblesec/jamendo/tracks',
                          'elisa.plugins.jamendo.controller:JamendoTracksPreviewListController'),
                        ],
    decorator_mappings=[('/poblesec/music/internet',
                         'elisa.plugins.jamendo.controller:jamendo_decorator')],
    )
